Description Usage Arguments Value Examples
View source: R/celsius_to_kelvin_doc.R
turn the units of a given temperature in Celsius degrees to Kelvin
1 | celsius_to_kelvin_doc(temp_C)
|
temp_C |
a numeric value that indicates the temperature in Celsius degrees |
a numeric that indicates the equivalent temperature in kelvin of a given temperature in Celsius
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.